==> cost-interface-0.3.35-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/GuestReceivePayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.GuestReceiveApplyVo;

import java.io.Serializable;
import java.util.Date;

public class GuestReceivePayVo implements Serializable{
    private static final long serialVersionUID = 6973137718653293201L;

    private GuestReceiveApplyVo guestReceiveApplyVo;
    /**
     *
     * 表字段 : guest_member_info.id
     */
    private Integer id;

    /**
     * 开始时间
     */
    private Date sDate;

    /**
     * 结束时间
     */
    private Date eDate;

    /**
     * 费用类型 编码
     */
    private String costTypeId;

    /**
     * 费用类型 名称
     */
    private String costTypeName;

    /**
     *
     * 表字段 : guest_member_info.apply_no
     */
    private String applyNo;

    /**
     * 行项目号
     * 表字段 : guest_member_info.item_no
     */
    private Integer itemNo;

    /**
     * 单位
     * 表字段 : guest_member_info.company
     */
    private String company;

    /**
     * 姓名
     * 表字段 : guest_member_info.people_name
     */
    private String peopleName;

    /**
     * 级别
     * 表字段 : guest_member_info.position_level
     */
    private String positionLevel;

    /**
     * 职务
     * 表字段 : guest_member_info.post
     */
    private String post;

    /**
     * 联系方式
     * 表字段 : guest_member_info.tel
     */
    private String tel;

    /**
     * 省
     * 表字段 : guest_member_info.province
     */
    private String province;

    /**
     * 市
     * 表字段 : guest_member_info.city
     */
    private String city;

    /**
     * 区县
     * 表字段 : guest_member_info.country
     */
    private String country;

    /**
     * 具体位置
     * 表字段 : guest_member_info.address_detail
     */
    private String addressDetail;

    /**
     * 身份证号码
     * 表字段 : guest_member_info.card_no
     */
    private String cardNo;

    /**
     * 督查意见
     * 表字段 : guest_member_info.audit_notes
     */
    private String auditNotes;

    /**
     *
     * 表字段 : guest_member_info.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : guest_member_info.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : guest_member_info.create_date
     */
    private Date createDate;

    public GuestReceiveApplyVo getGuestReceiveApplyVo() {
        return guestReceiveApplyVo;
    }

    public void setGuestReceiveApplyVo(GuestReceiveApplyVo guestReceiveApplyVo) {
        this.guestReceiveApplyVo = guestReceiveApplyVo;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Date getsDate() {
        return sDate;
    }

    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    public Date geteDate() {
        return eDate;
    }

    public void seteDate(Date eDate) {
        this.eDate = eDate;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }

    public String getPeopleName() {
        return peopleName;
    }

    public void setPeopleName(String peopleName) {
        this.peopleName = peopleName;
    }

    public String getPositionLevel() {
        return positionLevel;
    }

    public void setPositionLevel(String positionLevel) {
        this.positionLevel = positionLevel;
    }

    public String getPost() {
        return post;
    }

    public void setPost(String post) {
        this.post = post;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getAddressDetail() {
        return addressDetail;
    }

    public void setAddressDetail(String addressDetail) {
        this.addressDetail = addressDetail;
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public String getAuditNotes() {
        return auditNotes;
    }

    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }
}

==> cost-interface-0.3.41-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/pay/GuestReceivePayVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.pay;

import com.chinayanghe.tpm.cost.vo.out.datadetail.regist.GuestReceiveApplyVo;

import java.io.Serializable;
import java.util.Date;

public class GuestReceivePayVo implements Serializable{
    private static final long serialVersionUID = 6973137718653293201L;

    private GuestReceiveApplyVo applyVo;
    /**
     *
     * 表字段 : guest_member_info.id
     */
    private Integer id;

    /**
     * 开始时间
     */
    private Date sDate;

    /**
     * 结束时间
     */
    private Date eDate;

    /**
     * 费用类型 编码
     */
    private String costTypeId;

    /**
     * 费用类型 名称
     */
    private String costTypeName;

    /**
     *
     * 表字段 : guest_member_info.apply_no
     */
    private String applyNo;

    /**
     * 行项目号
     * 表字段 : guest_member_info.item_no
     */
    private Integer itemNo;

    /**
     * 单位
     * 表字段 : guest_member_info.company
     */
    private String company;

    /**
     * 姓名
     * 表字段 : guest_member_info.people_name
     */
    private String peopleName;

    /**
     * 级别
     * 表字段 : guest_member_info.position_level
     */
    private String positionLevel;

    /**
     * 职务
     * 表字段 : guest_member_info.post
     */
    private String post;

    /**
     * 联系方式
     * 表字段 : guest_member_info.tel
     */
    private String tel;

    /**
     * 省
     * 表字段 : guest_member_info.province
     */
    private String province;

    /**
     * 市
     * 表字段 : guest_member_info.city
     */
    private String city;

    /**
     * 区县
     * 表字段 : guest_member_info.country
     */
    private String country;

    /**
     * 具体位置
     * 表字段 : guest_member_info.address_detail
     */
    private String addressDetail;

    /**
     * 身份证号码
     * 表字段 : guest_member_info.card_no
     */
    private String cardNo;

    /**
     * 督查意见
     * 表字段 : guest_member_info.audit_notes
     */
    private String auditNotes;

    /**
     *
     * 表字段 : guest_member_info.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : guest_member_info.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : guest_member_info.create_date
     */
    private Date createDate;

    public GuestReceiveApplyVo getApplyVo() {
        return applyVo;
    }

    public void setApplyVo(GuestReceiveApplyVo applyVo) {
        this.applyVo = applyVo;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Date getsDate() {
        return sDate;
    }

    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    public Date geteDate() {
        return eDate;
    }

    public void seteDate(Date eDate) {
        this.eDate = eDate;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }

    public String getPeopleName() {
        return peopleName;
    }

    public void setPeopleName(String peopleName) {
        this.peopleName = peopleName;
    }

    public String getPositionLevel() {
        return positionLevel;
    }

    public void setPositionLevel(String positionLevel) {
        this.positionLevel = positionLevel;
    }

    public String getPost() {
        return post;
    }

    public void setPost(String post) {
        this.post = post;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getAddressDetail() {
        return addressDetail;
    }

    public void setAddressDetail(String addressDetail) {
        this.addressDetail = addressDetail;
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public String getAuditNotes() {
        return auditNotes;
    }

    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }
}
